*Configured
if "${gsdData}"=="" {
	di as error "Configure work environment by running init.do before running the code."
	error 1
}

set more off
*This do file replaces some of the variables which had missing information; incorporates the two rosters; and generates new variables for the analysis

use "${gsdData}/1-CleanInput/MLS.dta", clear

********************************************************************************
*1.1. UNANSWERED/MISSING RESPONSES
********************************************************************************
*Compulsory questions that were not answered
foreach var of varlist gender nationality product buy_bags kg_bag_buy sell_bags kg_bag_sell any_supplier trader_town_buy trader_town_sell sell_allyear postharvest_sell badharvest_sell storage No1Storage_Problem loan loan_best loan_more buyers_method buyers_preferred buyer_preferred_reason buyer_credit foreign trader_association priceinfo New_Selling_Markets routeinfo {
	gen `var'_m=0 
	replace `var'_m=1 if `var'==. | `var'<-1.00e+08
	sum `var'_m,  meanonly
       if r(mean)==0 {
		drop `var'_m
		}
}	
replace buying_market=. if buying_market<-1.00e+08 
replace selling_market=. if selling_market<-1.00e+08

********************************************************************************
*1.2. INCONSISTENCY IN ANSWERS
********************************************************************************
*All markets the respondent buys or sells to should also include the main market they selected
gen allmarkets_buy_m=0
forval i=1/23 {
	replace allmarkets_buy_m= 1 if allmarkets_buy__`i'==0 & buying_market==`i'
	}
	
gen allmarkets_sell_m=0
forval i=1/23 {
	replace allmarkets_sell_m= 1 if allmarkets_sell__`i'==0 & selling_market==`i'
	}
sum allmarkets_buy_m, meanonly
       if r(mean)==0 {
		drop allmarkets_buy_m
		}
sum allmarkets_sell_m, meanonly
       if r(mean)==0 {
		drop allmarkets_sell_m
		}
********************************************************************************
*1.3. UNUSUAL RESPONSES
********************************************************************************
*Number of bags bought and sold cannot be 0
gen buy_bags0_m=0
replace buy_bags0_m= 1 if buy_bags==0

gen sell_bags0_m=0
replace sell_bags0_m= 1 if sell_bags==0

gen buy_kg0_m=0
replace buy_bags0_m= 1 if kg_bag_buy==0

gen sell_kg0_m=0
replace sell_bags0_m= 1 if kg_bag_sell==0

*One trader reported 0 for both, replace with mean.
sum buy_bags, meanonly
replace buy_bags=r(mean) if buy_bags0_m==1

sum sell_bags, meanonly
replace sell_bags=r(mean) if sell_bags0_m==1

*Bags of grain bought and sold - sold shouldnt be much larger than bought
gen buy_kgs= buy_bags*kg_bag_buy
gen sell_kgs= sell_bags*kg_bag_sell
gen store_kgs= store_bags*kg_bag_store
gen bags_m=0
replace bags_m=1 if (sell_kgs>=buy_kgs*5)

*Unsure about 4 observations, replace with mean
sum sell_kgs, meanonly
replace sell_kgs=r(mean) if bags_m==1

drop *_m
*Time in a consistent format
foreach var of varlist buytraveltime_days buytraveltime_hrs buytraveltime_mins selltraveltime_days selltraveltime_hrs buytraveltime_mins buyroute_rainaccess_months buyroute_rainaccess_days sellroute_rainaccess_months sellroute_rainaccess_days buycheckpoint_duration_hrs buycheckpoint_duration_mins sellcheckpoint_duration_hrs sellcheckpoint_duration_mins {
	replace `var'=. if `var'<-1.00e+08
	}
	
replace buytraveltime_days = buytraveltime_days*24
replace buytraveltime_mins = buytraveltime_mins/60
gen buytraveltime = buytraveltime_days + buytraveltime_hrs + buytraveltime_mins
drop buytraveltime_*
lab var buytraveltime "Buying route time in hours"

replace selltraveltime_days = selltraveltime_days*24
replace selltraveltime_mins = selltraveltime_mins/60
gen selltraveltime = selltraveltime_days + selltraveltime_hrs + selltraveltime_mins
drop selltraveltime_*
lab var selltraveltime "Selling route time in hours"

replace buyroute_rainaccess_days = buyroute_rainaccess_days/30
gen buy_rainaccesstime = buyroute_rainaccess_months + buyroute_rainaccess_days
drop buyroute_rainaccess_*
lab var buy_rainaccesstime "Buying route inaccessible in months"

replace sellroute_rainaccess_days = sellroute_rainaccess_days/30
gen sell_rainaccesstime = sellroute_rainaccess_months + sellroute_rainaccess_days
drop sellroute_rainaccess_*
lab var sell_rainaccesstime "Selling route inaccessible in months"

replace buycheckpoint_duration_mins = buycheckpoint_duration_mins/60
gen buycheckpoint_duration = buycheckpoint_duration_hrs + buycheckpoint_duration_mins
drop buycheckpoint_duration_*
lab var buycheckpoint_duration "Buying route checkpoint duration in hours"

replace sellcheckpoint_duration_mins = sellcheckpoint_duration_mins/60
gen sellcheckpoint_duration = sellcheckpoint_duration_hrs + sellcheckpoint_duration_mins
drop sellcheckpoint_duration_*
lab var sellcheckpoint_duration "Selling route checkpoint duration in hours"

*Check if checkpoint duration is longer than total travel time
gen buycheckpoint_m=0
replace buycheckpoint_m=1 if buycheckpoint_duration>buytraveltime

gen sellcheckpoint_m=0
replace sellcheckpoint_m=1 if sellcheckpoint_duration>selltraveltime

sum buycheckpoint_m, meanonly
       if r(mean)==0 {
		drop buycheckpoint_m
		}
sum sellcheckpoint_m, meanonly
       if r(mean)==0 {
		drop sellcheckpoint_m
		}

********************************************************************************
*GENERATE NEW VARIABLES
********************************************************************************
*Define origin suplus and deficit markets and destination markets(buying and selling) 
gen origin="Deficit"
replace origin="Surplus" if inlist(town, 3, 7, 8, 9, 10, 11, 13) 
replace origin="" if town==.

gen destinationbuy="Deficit"
replace destinationbuy="Surplus" if inlist(buying_market,3, 7, 8, 9, 10, 11, 13) 
replace destinationbuy="" if buying_market==.

gen destinationsell="Deficit"
replace destinationsell="Surplus" if inlist(selling_market,3, 7, 8, 9, 10, 11, 13) 
replace destinationsell="" if selling_market==.

gen surplusdeficit=0
replace surplusdeficit=1 if origin=="Deficit" & destinationbuy=="Surplus"
replace surplusdeficit=1 if origin=="Deficit" & destinationsell=="Surplus"
replace surplusdeficit=1 if origin=="Surplus" & destinationbuy=="Deficit"
replace surplusdeficit=1 if origin=="Surplus" & destinationsell=="Deficit"
replace surplusdeficit=0 if missing(surplusdeficit)

gen surplussurplus=0
replace surplussurplus=1 if origin=="Surplus" & (destinationbuy=="Surplus" | destinationsell=="Surplus")
gen deficitdeficit=0
replace deficitdeficit=1 if origin=="Deficit" & (destinationbuy=="Deficit" | destinationsell=="Deficit")
replace surplussurplus=0 if missing(surplusdeficit)

*Number of times stopped due to damage as a proportion of number of trips to the market
gen buydamage_p = buydamage_time/buy_trips_num
gen selldamage_p = selldamage_time/sell_trips_num

*Number of times stopped due to no fuel available as a proportion of number of trips to the market
gen buyfuel_p = buyfreqfuel_shortage/buy_trips_num
gen sellfuel_p = sellfreqfuel_shortage/sell_trips_num

*Checkpoint duration as a proportion of total travel time
gen buycheck_p = buycheckpoint_duration/buytraveltime
gen sellcheck_p = sellcheckpoint_duration/selltraveltime

*Number of checkpoints encountered per hour
gen buycheck= buycheckpoints_num/buytraveltime
gen sellcheck= sellcheckpoints_num/selltraveltime

********************************************************************************
*GENERATING ROW TOTALS FOR SINGLE-SELECT VARIABLES
********************************************************************************
egen buyer_types_n=rowtotal(buyer_types*)
egen supplier_types_n=rowtotal(supplier_types*)
egen allmarkets_buy_n=rowtotal(allmarkets_buy*)
egen allmarkets_sell_n=rowtotal(allmarkets_sell*)
egen info_source_price_n=rowtotal(info_source_price*)
egen info_source_trade_n=rowtotal(info_source_trade_*)

********************************************************************************
*CREATE INDICATOR FOR SMALL, MEDIUM AND LARGE SCALE TRADERS
********************************************************************************
sum sell_kgs
replace sell_kgs=r(mean) if sell_kgs==0
gen scale=.
gen logsell_kgs=log(sell_kgs)
qui sum logsell_kgs, d
replace scale=1 if logsell_kgs<=r(p50)
replace scale=2 if logsell_kgs>r(p50)
label define tradescale 1 "Small-scale" 2 "Large-scale"
lab val scale tradescale

********************************************************************************
*RECODE VARIABLES
********************************************************************************
*Recode barrier variable
forval i=4/7{
	local k=`i'+1
	rename buyroute_barrier__`k' buyroute_barrier__`i'
	}

*Declare survey data
svyset _n [pweight=weight], strata(strata)
save "${gsdData}/1-CleanOutput/MLS_clean.dta", replace




