*Configured
if "${gsdData}"=="" {
	di as error "Configure work environment by running init.do before running the code."
	error 1
}

set more off
**Author: Menaal Ebrahim - mebrahim@worldbank.org
use "${gsdData}/1-CleanOutput/MLS_clean.dta", clear
********************************************************************************
*MODULE 1: BASIC INFORMATION
********************************************************************************
*Table 1: Profile of traders by area
tab gender, gen(male)
rename male1 Female
rename male2 Male
bysort town: gen obs = _N 
decode scale, gen(scale1)
decode product, gen(product1)
bysort town: egen scalem = mode(scale1), maxmode
bysort town: egen productm = mode(product1),maxmode
collapse (rawsum) Female (rawsum) Male (mean) age (firstnm) productm scalem (mean) business_years (firstnm) obs, by(town)
sort town
export excel using "${gsdOutput}\MLS_Graphs.xlsx", sheetreplace sheet("Raw data for Figure 1") firstrow(variables) 

*Table 2: Surplus to deficit trading partners
use "${gsdData}/1-CleanOutput/MLS_clean.dta", clear
decode town, gen(town1)
decode buying_market, gen(buying_market1)
decode selling_market, gen(selling_market1)
gen count0= _N 
keep if surplusdeficit==1
gen count1= _N
keep town1 origin buying_market1 destinationbuy selling_market1 destinationsell count0 count1
order town1 origin buying_market1 destinationbuy selling_market1 destinationsell count0 count1
sort origin town1 
duplicates drop
export excel using "${gsdOutput}\MLS_Graphs.xlsx", sheetreplace sheet("Raw data for Figure 2") firstrow(variables)

*Table 3: Surplus to surplus trading partners
use "${gsdData}/1-CleanOutput/MLS_clean.dta", clear
decode town, gen(town1)
decode buying_market, gen(buying_market1)
decode selling_market, gen(selling_market1)
bysort origin: gen count2= _N 
keep if surplussurplus==1
bysort origin: gen count3= _N 
keep town1 origin buying_market1 destinationbuy selling_market1 destinationsell count2 count3
order town1 origin buying_market1 destinationbuy selling_market1 destinationsell count2 count3
sort town1
duplicates drop
export excel using "${gsdOutput}\MLS_Graphs.xlsx", sheetreplace sheet("Raw data for Figure 3") firstrow(variables)

*Table 4: Deficit to deficit trading partners 
use "${gsdData}/1-CleanOutput/MLS_clean.dta", clear
decode town, gen(town1)
decode buying_market, gen(buying_market1)
decode selling_market, gen(selling_market1)
bysort origin: gen count4= _N 
keep if deficitdeficit==1
bysort origin: gen count5= _N 
keep town1 origin buying_market1 destinationbuy selling_market1 destinationsell count4 count5
order town1 origin buying_market1 destinationbuy selling_market1 destinationsell count4 count5
sort town1
duplicates drop
export excel using "${gsdOutput}\MLS_Graphs.xlsx", sheetreplace sheet("Raw data for Figure 4") firstrow(variables)

use "${gsdData}/1-CleanOutput/MLS_clean.dta", clear 
*Graph 1: Reason for not buying from local producers
qui tabout reason_nonlocal_supplier origin using "${gsdOutput}/Raw data for Figure 5.xls", svy percent c(col) ci2col npos(col) replace h1("Reason for not buying locally") f(1)
qui tabout reason_nonlocal_supplier product using "${gsdOutput}/Raw data for Figure 5.xls", svy percent c(col) ci2col npos(col) append h1("Reason for not buying locally") f(1)
qui tabout reason_nonlocal_supplier town using "${gsdOutput}/Raw data for Figure 5.xls", svy percent c(col) ci2col npos(col) append h1("Reason for not buying locally") f(1)
qui tabout reason_nonlocal_supplier gender using "${gsdOutput}/Raw data for Figure 5.xls", svy percent c(col) ci2col npos(col) append h1("Reason for not buying locally") f(1)

*Graph 2: Products sold by origin and scale
qui tabout product origin using "${gsdOutput}/Raw data for Figure 6.xls", svy percent c(col) ci2col npos(col) replace f(1)
qui tabout product scale using "${gsdOutput}/Raw data for Figure 6.xls", svy percent c(col) ci2col npos(col) append f(1)
qui tabout origin scale using "${gsdOutput}/Raw data for Figure 6.xls", svy percent c(col) ci2col npos(col) append f(1)

********************************************************************************
*MODULE 2: TRANSPORT BARRIERS
********************************************************************************
*Graph 1: Biggest transport barrier on buying and selling route
qui tabout buyroute_barrier__1 origin using "${gsdOutput}/Raw data for Figure 7.xls", svy percent c(col) ci2col npos(col) replace f(1)
forval i=2/7{
	qui tabout buyroute_barrier__`i' origin using "${gsdOutput}/Raw data for Figure 7.xls", svy percent c(col) ci2col npos(col) append f(1)	
}	
forval i=1/8{
	qui tabout sellroute_barrier__`i' origin using "${gsdOutput}/Raw data for Figure 7.xls", c(freq) append f(1)	
}
forval i=1/7{
	qui tabout buyroute_barrier__`i' scale using "${gsdOutput}/Raw data for Figure 7.xls", c(freq) append f(1)	
}

forval i=1/7{
	qui tabout sellroute_barrier__`i' scale using "${gsdOutput}/Raw data for Figure 7.xls", c(freq) append f(1)	
}
forval i=1/7{
	qui tabout buyroute_barrier__`i' town using "${gsdOutput}/Raw data for Figure 7.xls", svy percent c(col) ci2col npos(col) append f(1)
}
qui tabout buyfreqfuel_shortage town using "${gsdOutput}/Raw data for Figure 7.xls", svy percent c(row) ci2col npos(col) append f(1)
		
*Graph 2: Trader scale and how vehicles are accessed 
qui tabout buytype_transportacc scale using "${gsdOutput}/Raw data for Figure 8.xls", svy percent c(col) ci2col npos(col) replace h1("How vehicle is accessed") f(1)
qui tabout buytype_transportacc if scale==1 using "${gsdOutput}/Raw data for Figure 8.xls", svy sum c(mean buy_trips_num se lb ub) npos(col) append  h1("How vehicle is accessed") f(1)
qui tabout buytype_transportacc if scale==1 using "${gsdOutput}/Raw data for Figure 8.xls", svy sum c(mean sell_kgs se) npos(col) append  h1("How vehicle is accessed") f(1)
qui tabout buyprimary_vehicle if scale==1 using "${gsdOutput}/Raw data for Figure 8.xls", svy percent c(col) ci2col npos(col) append f(1)
qui tabout buytype_transportacc town using "${gsdOutput}/Raw data for Figure 8.xls", svy percent c(col) ci2col npos(col) append h1("How vehicle is accessed") f(1)

********************************************************************************
*MODULE 3: STORAGE 
********************************************************************************
*Graph 1: Trader scale, type of market and type of storage used
qui tabout storage scale using "${gsdOutput}/Raw data for Figure 9.xls", svy percent c(col) ci2col npos(col) replace h1("Storage") f(1)
qui tabout storage town using "${gsdOutput}/Raw data for Figure 9.xls", svy percent c(col) ci2col npos(col) append h1("Storage") f(1)
qui tabout storage_needs scale using "${gsdOutput}/Raw data for Figure 9.xls", svy percent c(row) ci2col npos(col) append h1("Storage needs met") f(1)
qui tabout storage_needs origin using "${gsdOutput}/Raw data for Figure 9.xls", svy percent c(row) ci2col npos(col) append h1("Storage needs met") f(1)
qui tabout storage_alt storage_needs using "${gsdOutput}/Raw data for Figure 9.xls", svy percent c(row) ci2col npos(col) append h1("Type of storage") f(1)
qui tabout storage_alt sell_allyear using "${gsdOutput}/Raw data for Figure 9.xls", svy percent c(row) ci2col npos(col) append f(1)
qui tabout storage_alt scale using "${gsdOutput}/Raw data for Figure 9.xls", svy percent c(row) ci2col npos(col) append f(1)
qui tabout storage sell_allyear using "${gsdOutput}/Raw data for Figure 9.xls", svy percent c(row) ci2col npos(col) append f(1)

*Graph 2: Biggest storage issues 
qui tabout No1Storage_Problem scale using "${gsdOutput}/Raw data for Figure 10.xls", svy percent c(col) ci2col npos(col) replace h1("Biggest storage problem") f(1)

********************************************************************************
*MODULE 4: FINANCIAL ACCESS
********************************************************************************
*Graph 1: Most common loan sources by scale 
qui tabout loan_sources__1 scale using "${gsdOutput}/Raw data for Figure 11.xls", svy percent c(col) ci2col npos(col) replace h1("Type of loan") f(1)
forval i=2/7 {
	qui tabout loan_sources__`i' scale using "${gsdOutput}/Raw data for Figure 11.xls", svy percent c(col) ci2col npos(col) append h1("Type of loan") f(1)
}
qui tabout loan_sources__1 town using "${gsdOutput}/Raw data for Figure 11.xls", c(freq) append h1("Type of loan") f(1)
forval i=2/7 {
	qui tabout loan_sources__`i' town using "${gsdOutput}/Raw data for Figure 11.xls", c(freq) append h1("Type of loan") f(1)
}

*Graph 2: Reason for not selling all year
qui tabout sell_whynot scale using "${gsdOutput}/Raw data for Figure 12.xls", svy percent c(col) ci2col npos(col) replace h1("Reason for not selling all year") f(1)
qui tabout sell_whynot town using "${gsdOutput}/Raw data for Figure 12.xls", svy percent c(col) ci2col npos(col) append h1("Reason for not selling all year") f(1)

********************************************************************************
*MODULE 5: INFORMATION ACCESS
********************************************************************************
*Graph 1: Membership in traders association by area and scale
qui tabout trader_association origin using "${gsdOutput}/Raw data for Figure 13.xls", svy percent c(col) ci2col npos(col) replace h1("Membership in traders association") f(1)
qui tabout trader_association scale using "${gsdOutput}/Raw data for Figure 13.xls", svy percent c(col) ci2col npos(col) append h1("Membership in traders association") f(1)
qui tabout trader_association town using "${gsdOutput}/Raw data for Figure 13.xls", svy percent c(col) ci2col npos(col) append h1("Membership in traders association") f(1)
qui tabout trader_association gender using "${gsdOutput}/Raw data for Figure 13.xls", svy percent c(col) ci2col npos(col) append h1("Membership in traders association") f(1)

*Graph 2: Willingness to be in traders association by area and scale 
qui tabout trader_association_interest origin using "${gsdOutput}/Raw data for Figure 14.xls", svy percent c(col) ci2col npos(col) replace h1("Interest in traders association") f(1)
qui tabout trader_association_interest scale using "${gsdOutput}/Raw data for Figure 14.xls", svy percent c(col) ci2col npos(col) append h1("Interest in traders association") f(1)
qui tabout trader_association_interest town using "${gsdOutput}/Raw data for Figure 14.xls", svy percent c(col) ci2col npos(col) append h1("Interest in traders association") f(1)
qui tabout trader_association gender using "${gsdOutput}/Raw data for Figure 13.xls", svy percent c(col) ci2col npos(col) append h1("Membership in traders association") f(1)

*Graph 3: Biggest benefit of being in a traders association
qui tabout ta_benefit scale using "${gsdOutput}/Raw data for Figure 15.xls", c(freq) replace h1("Biggest benefit from traders association") f(1)

*Graph 4: Best information recieved from ta 
qui tabout ta_info_benefit using "${gsdOutput}/Raw data for Figure 16.xls", c(freq) replace h1("Best information from traders association") f(1)

*Graph 5: Information on prices source by area 
qui tabout info_source_price__1 using "${gsdOutput}/Raw data for Figure 17.xls", c(freq) replace h1("Source of price information") f(1)
forval i=2/6{
	qui tabout info_source_price__`i' using "${gsdOutput}/Raw data for Figure 17.xls", c(freq) append h1("Source of price information") f(1)
}
********************************************************************************
*Export all results into one excel workbook
********************************************************************************
forval i=5/17 {
	insheet using "${gsdOutput}\Raw data for Figure `i'.xls", clear 
	export excel using "${gsdOutput}\MLS_Graphs.xlsx", sheetreplace sheet("Raw data for Figure `i'") firstrow(variables) 
    rm "${gsdOutput}\Raw data for Figure `i'.xls"
}
	
