*Configured
if "${gsdData}"=="" {
	di as error "Configure work environment by running init.do before running the code."
	error 1
}

set more off
*Split dataset - those that are trading with other towns and those that aren't
use "${gsdData}/1-CleanOutput/MLS_clean.dta", clear 
keep if missing(buying_market) & missing(selling_market)
order town, first
order buying_market, after(town)
order selling_market, after(buying_market)
order product, after(selling_market)
sort town product
save "${gsdTemp}/MLS_notrade_m.dta", replace

*For those who trade with other towns
use "${gsdData}/1-CleanOutput/MLS_clean.dta", clear
keep if !missing(buying_market) | !missing(selling_market)
keep if !missing(buypaved_road)
sort town product
save "${gsdTemp}/MLS_trade_m.dta", replace 

*Split again for buying and selling and then merge
*Buying
use "${gsdTemp}/MLS_trade_m.dta", clear
keep if !missing(buying_market)
keep town product *buy* origin
drop buy_bags- allmarkets_buy__23 buyuse_altroute buyprimary_vehicle- change_trade_buy buyer_types_n - allmarkets_buy_n buydamage_time buyfreqfuel_shortage buycheck_states buycheck_statestime buyaltroute_barrier buy_rainaccesstime buycheckpoint_duration buy_kgs

*Aggregate trasportation barrier variables - only consider the biggest barrier.
gen buyroute_barrier=""
forval i=1/7 {
	replace buyroute_barrier__`i'=. if buyroute_barrier__`i'!=1
	replace buyroute_barrier="buyroute_barrier__`i'" if buyroute_barrier__`i'==1
}
drop buyroute_barrier__*
replace buyroute_barrier="Lack of safety from conflict" if buyroute_barrier=="buyroute_barrier__1"
replace buyroute_barrier="High taxes" if buyroute_barrier=="buyroute_barrier__2"
replace buyroute_barrier="Poor road condition" if buyroute_barrier=="buyroute_barrier__3"
replace buyroute_barrier="Fuel shortages" if buyroute_barrier=="buyroute_barrier__4"
replace buyroute_barrier="Road accidents" if buyroute_barrier=="buyroute_barrier__5"
replace buyroute_barrier="Too many checkpoints" if buyroute_barrier=="buyroute_barrier__6"
replace buyroute_barrier="None" if buyroute_barrier=="buyroute_barrier__7"

*Generate post 2013 deterioration index
global buypcaList buyconflict_damage buyroute_conflictaccess buyfuelfreq_conflict buycheck_conflict buycheck_conflicttime conflict_buy_trips 
global buyxcomp 1

*Recode conflict variables
foreach var of global buypcaList {
	recode `var' (3 = 1 "Decreased") (-98 -99 2 = 2 "No change") (1 = 3 "Increased"), gen(n`var')
	drop `var'
	rename n`var' `var'
}
recode conflict_buy_trips (3 = 1 "Increased") (-98 -99 2 = 2 "No change")(1 = 3 "Decreased"), gen(nconflict)
drop conflict_buy_trips
rename nconflict conflict_buy_trips

pca $buypcaList, mineigen(1)
screeplot, yline(1)

*Score of First Component, normalized to scale 1 - 10
predict p1
summ p1         
gen buyconflictIndex = 1 + (p1 - `r(min)')*(10 - 1) / (`r(max)' - `r(min)')
histogram buyconflictIndex, normal scheme(s2mono) by(origin)

label var buyconflictIndex "Index of Exposure to Conflict - Buying"
drop p1 $buypcaList

*decode variables
foreach var of varlist town buying_market product buypaved_road reason_buy_trips buyaltroute_mean{
	decode `var', gen(`var'1)
	drop `var'
	rename `var'1 `var'
}
foreach var of varlist _all {
	bysort town buying_market: egen `var'2 = mode(`var'), maxmode
	drop `var'
	rename `var'2 `var'
}
bysort town buying_market product: gen N=_N
duplicates drop 

*Generate variables for division
*Surplus to deficit, deficit to deficit, and surplus to surplus
gen trade_flow=1
replace trade_flow=2 if origin=="Deficit" & destinationbuy=="Deficit" 
replace trade_flow=3 if origin=="Surplus" & destinationbuy=="Surplus"
lab define flow 1 "Surplus-Deficit" 2 "Deficit-Deficit" 3 "Surplus-Surplus"
lab val trade_flow flow

*Variable for major road or not
gen road=0
replace road=1 if (town=="Torit" & buying_market=="Juba") | (town=="Juba" & buying_market=="Torit")
replace road=1 if (town=="Wau" & buying_market=="Juba") | (town=="Juba" & buying_market=="Wau")
replace road=1 if (town=="Juba" & buying_market=="Bor Town") | (town=="Bor Town" & buying_market=="Juba")
replace road=1 if (town=="Wau" & buying_market=="Aweil") | (town=="Aweil" & buying_market=="Wau")
replace road=1 if (town=="Wau" & buying_market=="Rumbek") | (town=="Rumbek" & buying_market=="Wau")
replace road=1 if (town=="Juba" & buying_market=="Yambio") | (town=="Yambio" & buying_market=="Juba")
replace road=1 if (town=="Tonj South" & buying_market=="Wau") | (town=="Wau" & buying_market=="Tonj South")
replace road=1 if (town=="Rumbek" & buying_market=="Tonj South") | (town=="Tonj South" & buying_market=="Rumbek")
replace road=1 if (town=="Wau" & buying_market=="Yambio") | (town=="Yambio" & buying_market=="Wau")
replace road=1 if (town=="Wau" & buying_market=="Raga") | (town=="Raga" & buying_market=="Wau")
replace road=1 if (town=="Magwi" & buying_market=="Torit") | (town=="Torit" & buying_market=="Magwi")
lab define roads 0 "No major road" 1 "Major road"
lab val road roads

for OLD in var destinationbuy reason_buy_trips buy_trips_num buytraveltime buycheck buycheck_p buyfuel_p buydamage_p buypaved_road buyroute_barrier buyconflictIndex buyroute_rainaccess buyalt_route buyaltroute_mean \ NEW in new destination reason_trips trips_num traveltime check check_p fuel_p damage_p paved_road route_barrier conflictIndex rainaccess altroute altroute_type : rename OLD NEW

save "${gsdData}/1-CleanTemp/MLS_buying_m.dta", replace

*Selling
use "${gsdTemp}/MLS_trade_m.dta", clear
keep if !missing(selling_market)
keep town product *sell* origin
drop sell_bags- allmarkets_sell__23 sellprimary_vehicle- change_trade_sell allmarkets_sell_n selldamage_time sellfreqfuel_shortage sellcheck_states sellcheck_statestime selluse_altroute sellaltroute_barrier sell_rainaccesstime sellcheckpoint_duration sell_kgs logsell_kgs

*Aggregate trasportation barrier variables - only consider the biggest barrier.
gen sellroute_barrier=""
forval i=1/7 {
	replace sellroute_barrier__`i'=. if sellroute_barrier__`i'!=1
	replace sellroute_barrier="sellroute_barrier__`i'" if sellroute_barrier__`i'==1
}
drop sellroute_barrier__* 
replace sellroute_barrier="Lack of safety from conflict" if sellroute_barrier=="sellroute_barrier__1"
replace sellroute_barrier="High taxes" if sellroute_barrier=="sellroute_barrier__2"
replace sellroute_barrier="Poor road condition" if sellroute_barrier=="sellroute_barrier__3"
replace sellroute_barrier="Fuel shortages" if sellroute_barrier=="sellroute_barrier__4"
replace sellroute_barrier="Road accidents" if sellroute_barrier=="sellroute_barrier__5"
replace sellroute_barrier="Too many checkpoints" if sellroute_barrier=="sellroute_barrier__6"
replace sellroute_barrier="None" if sellroute_barrier=="sellroute_barrier__7"

*Generate post 2013 deterioration index
global sellpcaList sellconflict_damage sellroute_conflictaccess sellfuelfreq_conflict sellcheck_conflict sellcheck_conflicttime conflict_sell_trips 
global sellxcomp 1

*Recode conflict variables
foreach var of global sellpcaList {
	recode `var' (3 = 1 "Decreased") (-98 -99 2 = 2 "No change") (1 = 3 "Increased"), gen(n`var')
	drop `var'
	rename n`var' `var'
}
recode conflict_sell_trips (3 = 1 "Increased") (-98 -99 2 = 2 "No change")(1 = 3 "Decreased"), gen(nconflict)
drop conflict_sell_trips
rename nconflict conflict_sell_trips

pca $sellpcaList, mineigen(1)
screeplot, yline(1)

*Score of First Component, normalized to scale 1 - 10
predict p1
summ p1         
gen sellconflictIndex = 1 + (p1 - `r(min)')*(10 - 1) / (`r(max)' - `r(min)')
histogram sellconflictIndex, normal scheme(s2mono) by(origin)

label var sellconflictIndex "Index of Exposure to Conflict - Selling"
drop p1 $sellpcaList

*decode variables
foreach var of varlist town selling_market product sellpaved_road reason_sell_trips sellaltroute_mean{
	decode `var', gen(`var'1)
	drop `var'
	rename `var'1 `var'
}
foreach var of varlist _all {
	bysort town selling_market: egen `var'2 = mode(`var'), maxmode
	drop `var'
	rename `var'2 `var'
}
bysort town selling_market product: gen N=_N
duplicates drop 

*Generate variables for division
*Surplus to deficit, deficit to deficit, and surplus to surplus
gen trade_flow=1
replace trade_flow=2 if origin=="Deficit" & destinationsell=="Deficit" 
replace trade_flow=3 if origin=="Surplus" & destinationsell=="Surplus"
lab define flow 1 "Surplus-Deficit" 2 "Deficit-Deficit" 3 "Surplus-Surplus"
lab val trade_flow flow

*Variable for major road or not
gen road=0
replace road=1 if (town=="Torit" & selling_market=="Juba") | (town=="Juba" & selling_market=="Torit")
replace road=1 if (town=="Wau" & selling_market=="Juba") | (town=="Juba" & selling_market=="Wau")
replace road=1 if (town=="Juba" & selling_market=="Bor Town") | (town=="Bor Town" & selling_market=="Juba")
replace road=1 if (town=="Wau" & selling_market=="Aweil") | (town=="Aweil" & selling_market=="Wau")
replace road=1 if (town=="Wau" & selling_market=="Rumbek") | (town=="Rumbek" & selling_market=="Wau")
replace road=1 if (town=="Juba" & selling_market=="Yambio") | (town=="Yambio" & selling_market=="Juba")
replace road=1 if (town=="Tonj South" & selling_market=="Wau") | (town=="Wau" & selling_market=="Tonj South")
replace road=1 if (town=="Rumbek" & selling_market=="Tonj South") | (town=="Tonj South" & selling_market=="Rumbek")
replace road=1 if (town=="Wau" & selling_market=="Yambio") | (town=="Yambio" & selling_market=="Wau")
replace road=1 if (town=="Wau" & selling_market=="Raga") | (town=="Raga" & selling_market=="Wau")
replace road=1 if (town=="Magwi" & selling_market=="Torit") | (town=="Torit" & selling_market=="Magwi")

for OLD in var destinationsell reason_sell_trips sell_trips_num selltraveltime sellcheck sellcheck_p sellfuel_p selldamage_p sellpaved_road sellroute_barrier sellconflictIndex sellroute_rainaccess sellalt_route sellaltroute_mean \ NEW in new destination reason_trips trips_num traveltime check check_p fuel_p damage_p paved_road route_barrier conflictIndex rainaccess altroute altroute_type : rename OLD NEW

save "${gsdData}/1-CleanTemp/MLS_selling_m.dta", replace
append using "${gsdData}/1-CleanTemp/MLS_buying_m.dta"
sort town
gen Market=buying_market
replace Market=selling_market if missing(buying_market)
drop buying_market selling_market traveltime origin destination 
sort town Market

*Manually create an Integrated or not variable
gen Integrated=0
replace Integrated=1 if town=="Aweil" & Market=="Juba" & product=="Rice"
replace Integrated=1 if town=="Bor Town" & Market=="Juba" & product=="Rice"
replace Integrated=1 if town=="Bor Town" & Market=="Juba" & product=="Maize"
replace Integrated=1 if town=="Juba" & Market=="Aweil" & product=="Sorghum"
replace Integrated=1 if town=="Juba" & Market=="Bor Town" & product=="Sorghum"
replace Integrated=1 if town=="Rumbek" & Market=="Juba" & product=="Maize"
replace Integrated=1 if town=="Rumbek" & Market=="Juba" & product=="Rice"
replace Integrated=1 if town=="Torit" & Market=="Juba" & product=="Rice"
replace Integrated=1 if town=="Kuajok" & Market=="Rumbek" & product=="Maize"
replace Integrated=1 if town=="Magwi" & Market=="Juba" & product=="Maize"
replace Integrated=1 if town=="Magwi" & Market=="Torit" & product=="Rice"
replace Integrated=1 if town=="Maridi" & Market=="Juba" & product=="Rice"
replace Integrated=1 if town=="Maridi" & Market=="Rumbek" & product=="Rice"
replace Integrated=1 if town=="Tonj South" & Market=="Aweil" & product=="Maize"
replace Integrated=1 if town=="Tonj South" & Market=="Wau" & product=="Maize"
replace Integrated=1 if town=="Kuajok" & Market=="Raga" & product=="Rice"

bysort trade_flow: egen N_type=total(N)
egen total= total(N)
replace N_type=N_type/total
drop total
sort town Market

order town Market product trade_flow Integrated road paved_road trips_num check check_p fuel_p damage_p rainaccess altroute altroute_type conflictIndex N N_type reason_trips route_barrier
drop if town=="Rumbek East" | town=="Nimule"
drop if missing(route_barrier)

*Drop observations that aren't part of the integration analysis or are duplicates in terms of trading partners

drop paved_road rainaccess altroute altroute_type
export excel using "${gsdOutput}\MLS_Graphs.xlsx", sheetreplace sheet("Raw data for Figure 18") firstrow(variables) 
